:orphan:

.. |grappelli| replace:: Grappelli
.. |filebrowser| replace:: FileBrowser

.. _translation:

Translation
===========

Translation is done via `Transifex <https://www.transifex.net/projects/p/django-filebrowser/>`_.

Supported Languages
-------------------

see https://www.transifex.net/projects/p/django-filebrowser/resource/djangopo/